@@ -138,7 +138,8 @@ class Consul(object):
             token=None,
             scheme='http',
             consistency='default',
-            dc=None):
+            dc=None,
+            verify=True):
         """
         *token* is an optional `ACL token`_. If supplied it will be used by
         default for all requests made with this client session. It's still
@@ -152,11 +153,13 @@ class Consul(object):
 
         *dc* is the datacenter that this agent will communicate with.
         By default the datacenter of the host is used.
+
+        *verify* is whether to verify the SSL certificate for HTTPS requests
         """
 
         # TODO: Status
 
-        self.http = self.connect(host, port, scheme)
+        self.http = self.connect(host, port, scheme, verify)
         self.token = token
         self.scheme = scheme
         self.dc = dc
@@ -298,9 +301,9 @@ class Consul(object):
             *index* is the current Consul index, suitable for making subsequent
             calls to wait for changes since this query was last run.
 
-            *wait* the maximum duration to wait (e.g. '10ms') to retrieve
+            *wait* the maximum duration to wait (e.g. '10s') to retrieve
             a given index. this parameter is only applied if *index* is also
-            specified. the wait time by default is 10 minutes.
+            specified. the wait time by default is 5 minutes.
 
             *token* is an optional `ACL token`_ to apply to this request.
 
@@ -897,7 +900,7 @@ class Consul(object):
             return self.agent.http.get(
                 lambda x: json.loads(x.body), '/v1/catalog/datacenters')
 
-        def nodes(self, index=None, consistency=None, dc=None):
+        def nodes(self, index=None, wait=None, consistency=None, dc=None):
             """
             Returns a tuple of (*index*, *nodes*) of all nodes known
             about in the *dc* datacenter. *dc* defaults to the current
@@ -906,6 +909,10 @@ class Consul(object):
             *index* is the current Consul index, suitable for making subsequent
             calls to wait for changes since this query was last run.
 
+            *wait* the maximum duration to wait (e.g. '10s') to retrieve
+            a given index. this parameter is only applied if *index* is also
+            specified. the wait time by default is 5 minutes.
+
             *consistency* can be either 'default', 'consistent' or 'stale'. if
             not specified *consistency* will the consistency level this client
             was configured with.
@@ -929,6 +936,8 @@ class Consul(object):
                 params['dc'] = dc
             if index:
                 params['index'] = index
+                if wait:
+                    params['wait'] = wait
             consistency = consistency or self.agent.consistency
             if consistency in ('consistent', 'stale'):
                 params[consistency] = '1'
@@ -936,7 +945,7 @@ class Consul(object):
                 callback(is_json=True, index=True),
                 '/v1/catalog/nodes', params=params)
 
-        def services(self, index=None, consistency=None, dc=None):
+        def services(self, index=None, wait=None, consistency=None, dc=None):
             """
             Returns a tuple of (*index*, *services*) of all services known
             about in the *dc* datacenter. *dc* defaults to the current
@@ -945,6 +954,10 @@ class Consul(object):
             *index* is the current Consul index, suitable for making subsequent
             calls to wait for changes since this query was last run.
 
+            *wait* the maximum duration to wait (e.g. '10s') to retrieve
+            a given index. this parameter is only applied if *index* is also
+            specified. the wait time by default is 5 minutes.
+
             *consistency* can be either 'default', 'consistent' or 'stale'. if
             not specified *consistency* will the consistency level this client
             was configured with.
@@ -969,6 +982,8 @@ class Consul(object):
                 params['dc'] = dc
             if index:
                 params['index'] = index
+                if wait:
+                    params['wait'] = wait
             consistency = consistency or self.agent.consistency
             if consistency in ('consistent', 'stale'):
                 params[consistency] = '1'
@@ -976,7 +991,7 @@ class Consul(object):
                 callback(is_json=True, index=True),
                 '/v1/catalog/services', params=params)
 
-        def node(self, node, index=None, consistency=None, dc=None):
+        def node(self, node, index=None, wait=None, consistency=None, dc=None):
             """
             Returns a tuple of (*index*, *services*) of all services provided
             by *node*.
@@ -984,6 +999,10 @@ class Consul(object):
             *index* is the current Consul index, suitable for making subsequent
             calls to wait for changes since this query was last run.
 
+            *wait* the maximum duration to wait (e.g. '10s') to retrieve
+            a given index. this parameter is only applied if *index* is also
+            specified. the wait time by default is 5 minutes.
+
             *consistency* can be either 'default', 'consistent' or 'stale'. if
             not specified *consistency* will the consistency level this client
             was configured with.
@@ -1022,6 +1041,8 @@ class Consul(object):
                 params['dc'] = dc
             if index:
                 params['index'] = index
+                if wait:
+                    params['wait'] = wait
             consistency = consistency or self.agent.consistency
             if consistency in ('consistent', 'stale'):
                 params[consistency] = '1'
@@ -1033,6 +1054,7 @@ class Consul(object):
                 self,
                 service,
                 index=None,
+                wait=None,
                 tag=None,
                 consistency=None,
                 dc=None):
@@ -1044,6 +1066,10 @@ class Consul(object):
             *index* is the current Consul index, suitable for making subsequent
             calls to wait for changes since this query was last run.
 
+            *wait* the maximum duration to wait (e.g. '10s') to retrieve
+            a given index. this parameter is only applied if *index* is also
+            specified. the wait time by default is 5 minutes.
+
             If *tag* is provided, the list of nodes returned will be filtered
             by that tag.
 
@@ -1072,6 +1098,8 @@ class Consul(object):
                 params['tag'] = tag
             if index:
                 params['index'] = index
+                if wait:
+                    params['wait'] = wait
             consistency = consistency or self.agent.consistency
             if consistency in ('consistent', 'stale'):
                 params[consistency] = '1'
@@ -1089,6 +1117,7 @@ class Consul(object):
         def service(self,
                     service,
                     index=None,
+                    wait=None,
                     passing=None,
                     tag=None,
                     dc=None):
@@ -1098,6 +1127,10 @@ class Consul(object):
             *index* is the current Consul index, suitable for making subsequent
             calls to wait for changes since this query was last run.
 
+            *wait* the maximum duration to wait (e.g. '10s') to retrieve
+            a given index. this parameter is only applied if *index* is also
+            specified. the wait time by default is 5 minutes.
+
             *nodes* are the nodes providing the given service.
 
             Calling with *passing* set to True will filter results to only
@@ -1109,8 +1142,10 @@ class Consul(object):
             datacenter.
             """
             params = {}
-            if index is not None:
+            if index:
                 params['index'] = index
+                if wait:
+                    params['wait'] = wait
             if passing:
                 params['passing'] = '1'
             if tag is not None:
@@ -1127,7 +1162,7 @@ class Consul(object):
                 callback,
                 '/v1/health/service/%s' % service, params=params)
 
-        def state(self, name, index=None, dc=None):
+        def state(self, name, index=None, wait=None, dc=None):
             """
             Returns a tuple of (*index*, *nodes*)
 
@@ -1140,6 +1175,10 @@ class Consul(object):
             *index* is the current Consul index, suitable for making subsequent
             calls to wait for changes since this query was last run.
 
+            *wait* the maximum duration to wait (e.g. '10s') to retrieve
+            a given index. this parameter is only applied if *index* is also
+            specified. the wait time by default is 5 minutes.
+
             *dc* is the datacenter of the node and defaults to this agents
             datacenter.
 
@@ -1149,6 +1188,8 @@ class Consul(object):
             params = {}
             if index:
                 params['index'] = index
+                if wait:
+                    params['wait'] = wait
             dc = dc or self.agent.dc
             if dc:
                 params['dc'] = dc
@@ -1161,13 +1202,17 @@ class Consul(object):
                 callback,
                 '/v1/health/state/%s' % name, params=params)
 
-        def node(self, node, index=None, dc=None):
+        def node(self, node, index=None, wait=None, dc=None):
             """
             Returns a tuple of (*index*, *checks*)
 
             *index* is the current Consul index, suitable for making subsequent
             calls to wait for changes since this query was last run.
 
+            *wait* the maximum duration to wait (e.g. '10s') to retrieve
+            a given index. this parameter is only applied if *index* is also
+            specified. the wait time by default is 5 minutes.
+
             *dc* is the datacenter of the node and defaults to this agents
             datacenter.
 
@@ -1176,6 +1221,8 @@ class Consul(object):
             params = {}
             if index:
                 params['index'] = index
+                if wait:
+                    params['wait'] = wait
             dc = dc or self.agent.dc
             if dc:
                 params['dc'] = dc
@@ -1275,7 +1322,7 @@ class Consul(object):
                 callback(is_200=True),
                 '/v1/session/destroy/%s' % session_id, params=params)
 
-        def list(self, index=None, consistency=None, dc=None):
+        def list(self, index=None, wait=None, consistency=None, dc=None):
             """
             Returns a tuple of (*index*, *sessions*) of all active sessions in
             the *dc* datacenter. *dc* defaults to the current datacenter of
@@ -1284,6 +1331,10 @@ class Consul(object):
             *index* is the current Consul index, suitable for making subsequent
             calls to wait for changes since this query was last run.
 
+            *wait* the maximum duration to wait (e.g. '10s') to retrieve
+            a given index. this parameter is only applied if *index* is also
+            specified. the wait time by default is 5 minutes.
+
             *consistency* can be either 'default', 'consistent' or 'stale'. if
             not specified *consistency* will the consistency level this client
             was configured with.
@@ -1309,6 +1360,8 @@ class Consul(object):
                 params['dc'] = dc
             if index:
                 params['index'] = index
+                if wait:
+                    params['wait'] = wait
             consistency = consistency or self.agent.consistency
             if consistency in ('consistent', 'stale'):
                 params[consistency] = '1'
@@ -1316,7 +1369,7 @@ class Consul(object):
                 callback(is_json=True, index=True),
                 '/v1/session/list', params=params)
 
-        def node(self, node, index=None, consistency=None, dc=None):
+        def node(self, node, index=None, wait=None, consistency=None, dc=None):
             """
             Returns a tuple of (*index*, *sessions*) as per *session.list*, but
             filters the sessions returned to only those active for *node*.
@@ -1324,6 +1377,10 @@ class Consul(object):
             *index* is the current Consul index, suitable for making subsequent
             calls to wait for changes since this query was last run.
 
+            *wait* the maximum duration to wait (e.g. '10s') to retrieve
+            a given index. this parameter is only applied if *index* is also
+            specified. the wait time by default is 5 minutes.
+
             *consistency* can be either 'default', 'consistent' or 'stale'. if
             not specified *consistency* will the consistency level this client
             was configured with.
@@ -1334,6 +1391,8 @@ class Consul(object):
                 params['dc'] = dc
             if index:
                 params['index'] = index
+                if wait:
+                    params['wait'] = wait
             consistency = consistency or self.agent.consistency
             if consistency in ('consistent', 'stale'):
                 params[consistency] = '1'
@@ -1341,7 +1400,12 @@ class Consul(object):
                 callback(is_json=True, index=True),
                 '/v1/session/node/%s' % node, params=params)
 
-        def info(self, session_id, index=None, consistency=None, dc=None):
+        def info(self,
+                 session_id,
+                 index=None,
+                 wait=None,
+                 consistency=None,
+                 dc=None):
             """
             Returns a tuple of (*index*, *session*) for the session
             *session_id* in the *dc* datacenter. *dc* defaults to the current
@@ -1350,6 +1414,10 @@ class Consul(object):
             *index* is the current Consul index, suitable for making subsequent
             calls to wait for changes since this query was last run.
 
+            *wait* the maximum duration to wait (e.g. '10s') to retrieve
+            a given index. this parameter is only applied if *index* is also
+            specified. the wait time by default is 5 minutes.
+
             *consistency* can be either 'default', 'consistent' or 'stale'. if
             not specified *consistency* will the consistency level this client
             was configured with.
@@ -1360,6 +1428,8 @@ class Consul(object):
                 params['dc'] = dc
             if index:
                 params['index'] = index
+                if wait:
+                    params['wait'] = wait
             consistency = consistency or self.agent.consistency
             if consistency in ('consistent', 'stale'):
                 params[consistency] = '1'
